@@ -1785,13 +1785,11 @@ class Bitbucket(AtlassianRestAPI):
         files = {
             'plugin': open(plugin_path, 'rb')
         }
-        headers = {
-            'X-Atlassian-Token': 'nocheck'
-        }
-        upm_token = self.request(method='GET', path='rest/plugins/1.0/', headers=headers, trailing=True).headers[
-            'upm-token']
+        upm_token = \
+            self.request(method='GET', path='rest/plugins/1.0/', headers=self.no_check_headers, trailing=True).headers[
+                'upm-token']
         url = 'rest/plugins/1.0/?token={upm_token}'.format(upm_token=upm_token)
-        return self.post(url, files=files, headers=headers)
+        return self.post(url, files=files, headers=self.no_check_headers)
 
     def upload_file(self, project, repository, content, message, branch, filename):
         """
@@ -2170,3 +2168,56 @@ class Bitbucket(AtlassianRestAPI):
             repoKey=repo_key,
             idCondition=id_condition)
         return self.delete(url) or {}
+
+    def get_associated_build_statuses(self, commit):
+        """
+        To get the build statuses associated with a commit.
+        :commit: str- commit id
+        :return:
+        """
+        if not self.cloud:
+            url = '/rest/build-status/1.0/commits/{commitId}'.format(commitId=commit)
+        else:
+            url = '/rest/build-status/2.0/commits/{commitId}'.format(commitId=commit)
+
+        return self.get(url)
+
+    def get_announcement_banner(self):
+        """
+        Gets the announcement banner, if one exists and is available to the user
+        :return:
+        """
+        if not self.cloud:
+            url = "rest/api/1.0/admin/banner"
+        else:
+            url = "rest/api/2.0/admin/banner"
+        return self.get(url)
+
+    def set_announcement_banner(self, body):
+        """
+        Sets the announcement banner with the provided JSON.
+        Only users authenticated as Admins may call this resource
+        :param body
+            {
+                "id": "https://docs.atlassian.com/jira/REST/schema/rest-announcement-banner#",
+                "title": "Rest Announcement Banner",
+                "type": "object"
+            }
+        :return:
+        """
+        if not self.cloud:
+            url = "rest/api/1.0/admin/banner"
+        else:
+            url = "rest/api/2.0/admin/banner"
+        return self.put(url, data=body)
+
+    def delete_announcement_banner(self):
+        """
+        Gets the announcement banner, if one exists and is available to the user
+        :return:
+        """
+        if not self.cloud:
+            url = "rest/api/1.0/admin/banner"
+        else:
+            url = "rest/api/2.0/admin/banner"
+        return self.delete(url)
