@@ -562,7 +562,7 @@ class Jira(AtlassianRestAPI):
         for key in issue_list:
             if re.match(jira_issue_regex, key):
                 matched_issue_keys.append(key)
-        jql = 'key in ({})'.format(', '.join(matched_issue_keys))
+        jql = 'key in ({})'.format(', '.join(set(matched_issue_keys)))
         query_result = self.jql(jql, fields=fields)
         if 'errorMessages' in query_result.keys():
             for message in query_result['errorMessages']:
@@ -1037,7 +1037,7 @@ class Jira(AtlassianRestAPI):
 
         if not issue_key or not self.issue_exists(issue_key):
             log.info('IssueKey is not provided or does not exists in destination. Will attempt to create an issue')
-            del fields['issuekey']
+            fields.pop("issuekey", None)
             return self.issue_create(fields)
 
         if self.issue_deleted(issue_key):
@@ -1045,7 +1045,7 @@ class Jira(AtlassianRestAPI):
             return None
 
         log.info('Issue "{issue_key}" exists, will update'.format(issue_key=issue_key))
-        del fields['issuekey']
+        fields.pop("issuekey", None)
         return self.issue_update(issue_key, fields)
 
     def issue_add_comment(self, issue_key, comment, visibility=None):
@@ -1458,13 +1458,11 @@ class Jira(AtlassianRestAPI):
         files = {
             'plugin': open(plugin_path, 'rb')
         }
-        headers = {
-            'X-Atlassian-Token': 'nocheck'
-        }
-        upm_token = self.request(method='GET', path='rest/plugins/1.0/', headers=headers, trailing=True).headers[
-            'upm-token']
+        upm_token = \
+            self.request(method='GET', path='rest/plugins/1.0/', headers=self.no_check_headers, trailing=True).headers[
+                'upm-token']
         url = 'rest/plugins/1.0/?token={upm_token}'.format(upm_token=upm_token)
-        return self.post(url, files=files, headers=headers)
+        return self.post(url, files=files, headers=self.no_check_headers)
 
     def delete_plugin(self, plugin_key):
         """
